@@ -11,16 +11,21 @@ import subprocess, tempfile, os, time
 from setup import Command, installer_name
 from setup.build_environment import HOST, PROJECT
 
+BASE_RSYNC = ['rsync', '-avz', '--delete']
+EXCLUDES = []
+for x in [
+    'src/calibre/plugins', 'src/calibre/manual', 'src/calibre/trac',
+    '.bzr', '.build', '.svn', 'build', 'dist', 'imgsrc', '*.pyc', '*.pyo', '*.swp',
+    '*.swo']:
+    EXCLUDES.extend(['--exclude', x])
+SAFE_EXCLUDES = ['"%s"'%x if '*' in x else x for x in EXCLUDES]
+
 class Rsync(Command):
 
     description = 'Sync source tree from development machine'
 
-    SYNC_CMD = ('rsync -avz --delete --exclude src/calibre/plugins '
-               '--exclude src/calibre/manual --exclude src/calibre/trac '
-               '--exclude .bzr --exclude .build --exclude .svn --exclude build --exclude dist '
-               '--exclude imgsrc '
-               '--exclude "*.pyc" --exclude "*.pyo" --exclude "*.swp" --exclude "*.swo" '
-               'rsync://{host}/work/{project} ..')
+    SYNC_CMD = ' '.join(BASE_RSYNC+SAFE_EXCLUDES+
+            ['rsync://{host}/work/{project}', '..'])
 
     def run(self, opts):
         cmd = self.SYNC_CMD.format(host=HOST, project=PROJECT)
@@ -28,6 +33,27 @@ class Rsync(Command):
         subprocess.check_call(cmd, shell=True)
 
 
+class Push(Command):
+
+    description = 'Push code to another host'
+
+    def run(self, opts):
+        from threading import Thread
+        threads = []
+        for host in (
+            r'Owner@winxp:/cygdrive/c/Documents\ and\ Settings/Owner/calibre',
+            'kovid@ox:calibre',
+            r'kovid@win7:/cygdrive/c/Users/kovid/calibre',
+            ):
+            rcmd = BASE_RSYNC + EXCLUDES + ['.', host]
+            print '\n\nPushing to:', host, '\n'
+            threads.append(Thread(target=subprocess.check_call, args=(rcmd,)))
+            threads[-1].start()
+        for thread in threads:
+            thread.join()
+
+
+
 class VMInstaller(Command):
 
     EXTRA_SLEEP = 5
@@ -123,7 +149,7 @@ class VMInstaller(Command):
         subprocess.check_call(['scp',
             self.VM_NAME+':build/calibre/'+installer, 'dist'])
         if not os.path.exists(installer):
-            self.warn('Failed to download installer')
+            self.warn('Failed to download installer: '+installer)
             raise SystemExit(1)
 
     def clean(self):
