@@ -21,6 +21,7 @@ from calibre.devices.usbms.driver import USBMS
 class EB600(USBMS):
 
     name           = 'Netronix EB600 Device Interface'
+    gui_name       = 'Netronix EB600'
     description    = _('Communicate with the EB600 eBook reader.')
     author         = 'Kovid Goyal'
     supported_platforms = ['windows', 'osx', 'linux']
@@ -182,9 +183,8 @@ class BOOQ(EB600):
 
     FORMATS = ['epub', 'mobi', 'prc', 'fb2', 'pdf', 'doc', 'rtf', 'txt', 'html']
 
-    VENDOR_NAME = 'NETRONIX'
-    WINDOWS_MAIN_MEM = 'EB600'
-    WINDOWS_CARD_A_MEM = 'EB600'
+    VENDOR_NAME = ['NETRONIX', '36LBOOKS']
+    WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['EB600', 'ELEQTOR']
 
 class MENTOR(EB600):
 
