@@ -49,7 +49,6 @@ class CHMInput(InputFormatPlugin):
             log.debug('stream.name=%s' % stream.name)
             mainname = self._chmtohtml(tdir, chm_name, no_images, log)
             mainpath = os.path.join(tdir, mainname)
-            #raw_input()
 
             metadata = get_metadata_from_reader(self._chm_reader)
 
@@ -76,7 +75,7 @@ class CHMInput(InputFormatPlugin):
     def _create_oebbook(self, hhcpath, basedir, opts, log, mi):
         from calibre.ebooks.conversion.plumber import create_oebbook
         from calibre.ebooks.oeb.base import DirContainer
-        oeb = create_oebbook(log, None, opts, self,
+        oeb = create_oebbook(log, None, opts,
                 encoding=opts.input_encoding, populate=False)
         self.oeb = oeb
 
@@ -141,10 +140,9 @@ class CHMInput(InputFormatPlugin):
         log.debug('Found %d section nodes' % len(chapters))
         htmlpath = os.path.splitext(hhcpath)[0] + ".html"
         f = open(htmlpath, 'wb')
-        f.write('<html><head><meta http-equiv="Content-type"'
-                ' content="text/html;charset=UTF-8" /></head><body>\n')
-
         if chapters:
+            f.write('<html><head><meta http-equiv="Content-type"'
+                ' content="text/html;charset=UTF-8" /></head><body>\n')
             path0 = chapters[0][1]
             subpath = os.path.dirname(path0)
 
@@ -158,7 +156,9 @@ class CHMInput(InputFormatPlugin):
                     url = url.encode('utf-8')
                 f.write(url)
 
-        f.write("</body></html>")
+            f.write("</body></html>")
+        else:
+            f.write(hhcdata)
         f.close()
         return htmlpath
 
@@ -177,6 +177,7 @@ class CHMInput(InputFormatPlugin):
 
             chapter_path = None
             if match_string(node.tag, 'object') and match_string(node.attrib['type'], 'text/sitemap'):
+                chapter_title = None
                 for child in node:
                     if match_string(child.tag,'param') and match_string(child.attrib['name'], 'name'):
                         chapter_title = child.attrib['value']
