@@ -83,6 +83,7 @@ class RTFInput(InputFormatPlugin):
                 os.mkdir(debug_dir)
                 debug_dir = 'rtfdebug'
                 run_lev = 4
+                self.log('Running RTFParser in debug mode')
             except:
                 pass
         parser = ParseRtf(
@@ -230,22 +231,6 @@ class RTFInput(InputFormatPlugin):
         with open('styles.css', 'ab') as f:
             f.write(css)
 
-    # def preprocess(self, fname):
-        # self.log('\tPreprocessing to convert unicode characters')
-        # try:
-            # data = open(fname, 'rb').read()
-            # from calibre.ebooks.rtf.preprocess import RtfTokenizer, RtfTokenParser
-            # tokenizer = RtfTokenizer(data)
-            # tokens = RtfTokenParser(tokenizer.tokens)
-            # data = tokens.toRTF()
-            # fname = 'preprocessed.rtf'
-            # with open(fname, 'wb') as f:
-                # f.write(data)
-        # except:
-            # self.log.exception(
-            # 'Failed to preprocess RTF to convert unicode sequences, ignoring...')
-        # return fname
-
     def convert_borders(self, doc):
         border_styles = []
         style_map = {}
@@ -280,8 +265,6 @@ class RTFInput(InputFormatPlugin):
         self.opts = options
         self.log = log
         self.log('Converting RTF to XML...')
-        #Name of the preprocesssed RTF file
-        # fname = self.preprocess(stream.name)
         try:
             xml = self.generate_xml(stream.name)
         except RtfInvalidCodeException, e:
@@ -335,3 +318,4 @@ class RTFInput(InputFormatPlugin):
         opf.render(open('metadata.opf', 'wb'))
         return os.path.abspath('metadata.opf')
 
+
