@@ -126,12 +126,6 @@ class Tokenize:
         tokens = re.split(self.__splitexp, input_file)
         #remove empty tokens and \n
         return filter(lambda x: len(x) > 0 and x != '\n', tokens)
-        #input_file = re.sub(self.__utf_exp, self.__from_ms_to_utf8, input_file)
-        # line = re.sub( self.__neg_utf_exp, self.__neg_unicode_func, line)
-        # this is for older RTF
-        #line = re.sub(self.__par_exp, '\\par ', line)
-        #return filter(lambda x: len(x) > 0, \
-            #(self.__remove_line.sub('', x) for x in tokens)) 
 
     def __compile_expressions(self):
         SIMPLE_RPL = {
@@ -160,7 +154,7 @@ class Tokenize:
             }
         self.__replace_spchar = MReplace(SIMPLE_RPL)
         #add ;? in case of char following \u
-        self.__ms_hex_exp = re.compile(r"\\\'([0-9a-fA-F]{2})") #r"\\\'(..)"
+        self.__ms_hex_exp = re.compile(r"\\\'([0-9a-fA-F]{2})")
         self.__utf_exp = re.compile(r"\\u(-?\d{3,6}) ?")
         self.__bin_exp = re.compile(r"(?:\\bin(-?\d{0,10})[\n ]+)[01\n]+")
         #manage upr/ud situations
@@ -172,14 +166,21 @@ class Tokenize:
         self.__splitexp = re.compile(r"(\\[{}]|\n|\\[^\s\\{}&]+(?:[ \t\r\f\v])?)")
         #this is for old RTF
         self.__par_exp = re.compile(r'\\\n+')
-        # self.__par_exp = re.compile(r'\\$')
+        #handle cw using a digit as argument and without space as delimiter
+        self.__cwdigit_exp = re.compile(r"(\\[a-zA-Z]+[\-0-9]+)([^0-9 \\]+)")
         #self.__bin_exp = re.compile(r"\\bin(-?\d{1,8}) {0,1}")
         #self.__utf_exp = re.compile(r"^\\u(-?\d{3,6})")
         #self.__splitexp = re.compile(r"(\\[\\{}]|{|}|\n|\\[^\s\\{}&]+(?:\s)?)")
         #self.__remove_line = re.compile(r'\n+')
-        #self.__mixed_exp = re.compile(r"(\\[a-zA-Z]+\d+)(\D+)")
         ##self.num_exp = re.compile(r"(\*|:|[a-zA-Z]+)(.*)")
 
+    def __correct_spliting(self, token):
+        match_obj = re.search(self.__cwdigit_exp, token)
+        if match_obj is None:
+            return token
+        else:
+            return '%s\n%s' % (match_obj.group(1), match_obj.group(2))
+
     def tokenize(self):
         """Main class for handling other methods. Reads the file \
         , uses method self.sub_reg to make basic substitutions,\
@@ -187,7 +188,7 @@ class Tokenize:
         #read
         with open(self.__file, 'r') as read_obj:
             input_file = read_obj.read()
-        
+
         #process simple replacements and split giving us a correct list
         #remove '' and \n in the process
         tokens = self.__sub_reg_split(input_file)
@@ -195,7 +196,9 @@ class Tokenize:
         tokens = map(self.__unicode_process, tokens)
         #remove empty items created by removing \uc
         tokens = filter(lambda x: len(x) > 0, tokens)
-        
+        #handles bothersome cases
+        tokens = map(self.__correct_spliting, tokens)
+
         #write
         with open(self.__write_to, 'wb') as write_obj:
             write_obj.write('\n'.join(tokens))
@@ -203,11 +206,9 @@ class Tokenize:
         copy_obj = copy.Copy(bug_handler = self.__bug_handler)
         if self.__copy:
             copy_obj.copy_file(self.__write_to, "tokenize.data")
-        # if self.__out_file:
-            # self.__file = self.__out_file
         copy_obj.rename(self.__write_to, self.__file)
         os.remove(self.__write_to)
-        
+
         #self.__special_tokens = [ '_', '~', "'", '{', '}' ]
 
 # import sys
@@ -223,4 +224,4 @@ class Tokenize:
 
 
 # if __name__ == '__main__':
-    # sys.exit(main())
\ No newline at end of file
+    # sys.exit(main())
