@@ -17,7 +17,7 @@ from calibre.gui2.actions import InterfaceAction
 class GenerateCatalogAction(InterfaceAction):
 
     name = 'Generate Catalog'
-    action_spec = (_('Create catalog of books in your calibre library'), None, None, None)
+    action_spec = (_('Create a catalog of the books in your calibre library'), None, None, None)
     dont_add_to = frozenset(['toolbar-device', 'context-menu-device'])
 
     def generate_catalog(self):
