@@ -11,9 +11,11 @@ class PluginWidget(Widget, Ui_Form):
 
     TITLE = _('FB2 Input')
     HELP = _('Options specific to')+' FB2 '+_('input')
+    COMMIT_NAME = 'fb2_input'
+    ICON = I('mimetypes/fb2.png')
 
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
-        Widget.__init__(self, parent, 'fb2_input',
+        Widget.__init__(self, parent,
             ['no_inline_fb2_toc'])
         self.db, self.book_id = db, book_id
         self.initialize_options(get_option, get_help, db, book_id)
