@@ -70,9 +70,6 @@ class MetadataWidget(Widget, Ui_Form):
     def initialize_metadata_options(self):
         self.initialize_combos()
         self.author.editTextChanged.connect(self.deduce_author_sort)
-        self.author.set_separator('&')
-        self.author.set_space_before_sep(True)
-        self.author.update_items_cache(self.db.all_author_names())
 
         mi = self.db.get_metadata(self.book_id, index_is_id=True)
         self.title.setText(mi.title)
@@ -109,6 +106,9 @@ class MetadataWidget(Widget, Ui_Form):
     def initalize_authors(self):
         all_authors = self.db.all_authors()
         all_authors.sort(key=lambda x : sort_key(x[1]))
+        self.author.set_separator('&')
+        self.author.set_space_before_sep(True)
+        self.author.update_items_cache(self.db.all_author_names())
 
         for i in all_authors:
             id, name = i
@@ -124,6 +124,8 @@ class MetadataWidget(Widget, Ui_Form):
     def initialize_series(self):
         all_series = self.db.all_series()
         all_series.sort(key=lambda x : sort_key(x[1]))
+        self.series.set_separator(None)
+        self.series.update_items_cache([x[1] for x in all_series])
 
         for i in all_series:
             id, name = i
@@ -133,6 +135,8 @@ class MetadataWidget(Widget, Ui_Form):
     def initialize_publisher(self):
         all_publishers = self.db.all_publishers()
         all_publishers.sort(key=lambda x : sort_key(x[1]))
+        self.publisher.set_separator(None)
+        self.publisher.update_items_cache([x[1] for x in all_publishers])
 
         for i in all_publishers:
             id, name = i
