@@ -7,7 +7,7 @@ import os, traceback, Queue, time, cStringIO, re, sys
 from threading import Thread
 
 from PyQt4.Qt import QMenu, QAction, QActionGroup, QIcon, SIGNAL, \
-                     Qt, pyqtSignal, QDialog, QMessageBox
+                     Qt, pyqtSignal, QDialog
 
 from calibre.customize.ui import available_input_formats, available_output_formats, \
     device_plugins
@@ -609,10 +609,8 @@ class DeviceMixin(object): # {{{
         autos = u'\n'.join(map(unicode, map(force_unicode, autos)))
         return self.ask_a_yes_no_question(
                 _('No suitable formats'), msg,
-                buttons=QMessageBox.Yes|QMessageBox.Cancel,
                 ans_when_user_unavailable=True,
-                det_msg=autos,
-                show_copy_button=False
+                det_msg=autos
         )
 
     def set_default_thumbnail(self, height):
@@ -689,7 +687,7 @@ class DeviceMixin(object): # {{{
         except:
             pass
         if not self.device_error_dialog.isVisible():
-            self.device_error_dialog.setDetailedText(job.details)
+            self.device_error_dialog.set_details(job.details)
             self.device_error_dialog.show()
 
     # Device connected {{{
@@ -840,9 +838,10 @@ class DeviceMixin(object): # {{{
                             format_count[f] = 1
             for f in self.device_manager.device.settings().format_map:
                 if f in format_count.keys():
-                    formats.append((f, _('%i of %i Books' % (format_count[f], len(rows))), True if f in aval_out_formats else False))
+                    formats.append((f, _('%i of %i Books') % (format_count[f],
+                        len(rows)), True if f in aval_out_formats else False))
                 elif f in aval_out_formats:
-                    formats.append((f, _('0 of %i Books' % len(rows)), True))
+                    formats.append((f, _('0 of %i Books') % len(rows), True))
             d = ChooseFormatDeviceDialog(self, _('Choose format to send to device'), formats)
             if d.exec_() != QDialog.Accepted:
                 return
@@ -873,6 +872,16 @@ class DeviceMixin(object): # {{{
             self.send_by_mail(to, fmts, delete)
 
     def cover_to_thumbnail(self, data):
+        if self.device_manager.device and \
+                hasattr(self.device_manager.device, 'THUMBNAIL_WIDTH'):
+            try:
+                return thumbnail(data,
+                                 self.device_manager.device.THUMBNAIL_WIDTH,
+                                 self.device_manager.device.THUMBNAIL_HEIGHT,
+                                 preserve_aspect_ratio=False)
+            except:
+                pass
+            return
         ht = self.device_manager.device.THUMBNAIL_HEIGHT \
                 if self.device_manager else DevicePlugin.THUMBNAIL_HEIGHT
         try:
@@ -1274,6 +1283,8 @@ class DeviceMixin(object): # {{{
             x = x.lower() if x else ''
             return string_pat.sub('', x)
 
+        update_metadata = prefs['manage_device_metadata'] == 'on_connect'
+
         # Force a reset if the caches are not initialized
         if reset or not hasattr(self, 'db_book_title_cache'):
             # Build a cache (map) of the library, so the search isn't On**2
@@ -1286,8 +1297,13 @@ class DeviceMixin(object): # {{{
             except:
                 return False
 
+            get_covers = False
+            if update_metadata and self.device_manager.is_device_connected:
+                if self.device_manager.device.WANTS_UPDATED_THUMBNAILS:
+                    get_covers = True
+
             for id in db.data.iterallids():
-                mi = db.get_metadata(id, index_is_id=True)
+                mi = db.get_metadata(id, index_is_id=True, get_cover=get_covers)
                 title = clean_string(mi.title)
                 if title not in db_book_title_cache:
                     db_book_title_cache[title] = \
@@ -1313,7 +1329,6 @@ class DeviceMixin(object): # {{{
         # the application_id to the db_id of the matching book. This value
         # will be used by books_on_device to indicate matches.
 
-        update_metadata = prefs['manage_device_metadata'] == 'on_connect'
         for booklist in booklists:
             for book in booklist:
                 book.in_library = None
@@ -1384,6 +1399,12 @@ class DeviceMixin(object): # {{{
 
         if update_metadata:
             if self.device_manager.is_device_connected:
+                if self.device_manager.device.WANTS_UPDATED_THUMBNAILS:
+                    for blist in booklists:
+                        for book in blist:
+                            if book.cover and os.access(book.cover, os.R_OK):
+                                book.thumbnail = \
+                                    self.cover_to_thumbnail(open(book.cover, 'rb').read())
                 plugboards = self.library_view.model().db.prefs.get('plugboards', {})
                 self.device_manager.sync_booklists(
                                     Dispatcher(self.metadata_synced), booklists,
