@@ -87,7 +87,7 @@ class MainWindow(QMainWindow):
             fe = sio.getvalue()
             prints(fe, file=sys.stderr)
             msg = '<b>%s</b>:'%type.__name__ + unicode(str(value), 'utf8', 'replace')
-            error_dialog(self, _('ERROR: Unhandled exception'), msg, det_msg=fe,
+            error_dialog(self, _('Unhandled exception'), msg, det_msg=fe,
                     show=True)
         except BaseException:
             pass
