@@ -17,11 +17,14 @@ from calibre.customize.ui import initialized_plugins, is_disabled, enable_plugin
                                  remove_plugin
 from calibre.gui2 import NONE, error_dialog, info_dialog, choose_files, \
         question_dialog
+from calibre.utils.search_query_parser import SearchQueryParser
+from calibre.utils.icu import lower
 
-class PluginModel(QAbstractItemModel): # {{{
+class PluginModel(QAbstractItemModel, SearchQueryParser): # {{{
 
     def __init__(self, *args):
         QAbstractItemModel.__init__(self, *args)
+        SearchQueryParser.__init__(self, ['all'])
         self.icon = QVariant(QIcon(I('plugins.png')))
         p = QIcon(self.icon).pixmap(32, 32, QIcon.Disabled, QIcon.On)
         self.disabled_icon = QVariant(QIcon(p))
@@ -40,6 +43,72 @@ class PluginModel(QAbstractItemModel): # {{{
         for plugins in self._data.values():
             plugins.sort(cmp=lambda x, y: cmp(x.name.lower(), y.name.lower()))
 
+    def universal_set(self):
+        ans = set([])
+        for c, category in enumerate(self.categories):
+            ans.add((c, -1))
+            for p, plugin in enumerate(self._data[category]):
+                ans.add((c, p))
+        return ans
+
+    def get_matches(self, location, query, candidates=None):
+        if candidates is None:
+            candidates = self.universal_set()
+        ans = set([])
+        if not query:
+            return ans
+        query = lower(query)
+        for c, p in candidates:
+            if p < 0:
+                if query in lower(self.categories[c]):
+                    ans.add((c, p))
+            else:
+                try:
+                    plugin = self._data[self.categories[c]][p]
+                except:
+                    continue
+            if query in lower(plugin.name) or query in lower(plugin.author) or \
+                    query in lower(plugin.description):
+                ans.add((c, p))
+        return ans
+
+    def find(self, query):
+        query = query.strip()
+        matches = self.parse(query)
+        if not matches:
+            return QModelIndex()
+        matches = list(sorted(matches))
+        c, p = matches[0]
+        cat_idx = self.index(c, 0, QModelIndex())
+        if p == -1:
+            return cat_idx
+        return self.index(p, 0, cat_idx)
+
+    def find_next(self, idx, query, backwards=False):
+        query = query.strip()
+        matches = self.parse(query)
+        if not matches:
+            return idx
+        if idx.parent().isValid():
+            loc = (idx.parent().row(), idx.row())
+        else:
+            loc = (idx.row(), -1)
+        if loc not in matches:
+            return self.find(query)
+        if len(matches) == 1:
+            return QModelIndex()
+        matches = list(sorted(matches))
+        i = matches.index(loc)
+        if backwards:
+            ans = i - 1 if i - 1 >= 0 else len(matches)-1
+        else:
+            ans = i + 1 if i + 1 < len(matches) else 0
+
+        ans = matches[ans]
+
+        return self.index(ans[0], 0, QModelIndex()) if ans[1] < 0 else \
+                self.index(ans[1], 0, self.index(ans[0], 0, QModelIndex()))
+
     def index(self, row, column, parent):
         if not self.hasIndex(row, column, parent):
             return QModelIndex()
@@ -127,6 +196,7 @@ class PluginModel(QAbstractItemModel): # {{{
                 return plugin
         return NONE
 
+
 # }}}
 
 class ConfigWidget(ConfigWidgetBase, Ui_Form):
@@ -144,6 +214,42 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.customize_plugin_button.clicked.connect(self.customize_plugin)
         self.remove_plugin_button.clicked.connect(self.remove_plugin)
         self.button_plugin_add.clicked.connect(self.add_plugin)
+        self.search.initialize('plugin_search_history',
+                help_text=_('Search for plugin'))
+        self.search.search.connect(self.find)
+        self.next_button.clicked.connect(self.find_next)
+        self.previous_button.clicked.connect(self.find_previous)
+
+    def find(self, query):
+        idx = self._plugin_model.find(query)
+        if not idx.isValid():
+            return info_dialog(self, _('No matches'),
+                    _('Could not find any matching plugins'), show=True,
+                    show_copy_button=False)
+        self.highlight_index(idx)
+
+    def highlight_index(self, idx):
+        self.plugin_view.scrollTo(idx)
+        self.plugin_view.selectionModel().select(idx,
+                self.plugin_view.selectionModel().ClearAndSelect)
+        self.plugin_view.setCurrentIndex(idx)
+
+    def find_next(self, *args):
+        idx = self.plugin_view.currentIndex()
+        if not idx.isValid():
+            idx = self._plugin_model.index(0, 0)
+        idx = self._plugin_model.find_next(idx,
+                unicode(self.search.currentText()))
+        self.highlight_index(idx)
+
+    def find_previous(self, *args):
+        idx = self.plugin_view.currentIndex()
+        if not idx.isValid():
+            idx = self._plugin_model.index(0, 0)
+        idx = self._plugin_model.find_next(idx,
+            unicode(self.search.currentText()), backwards=True)
+        self.highlight_index(idx)
+
 
     def toggle_plugin(self, *args):
         self.modify_plugin(op='toggle')
@@ -160,7 +266,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
     def add_plugin(self):
         path = choose_files(self, 'add a plugin dialog', _('Add plugin'),
-                filters=[(_('Plugins'), ['zip'])], all_files=False,
+                filters=[(_('Plugins') + ' (*.zip)', ['zip'])], all_files=False,
                     select_only_single_file=True)
         if not path:
             return
@@ -184,13 +290,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                     show=True, show_copy_button=False)
             idx = self._plugin_model.plugin_to_index_by_properties(plugin)
             if idx.isValid():
-                self.plugin_view.scrollTo(idx,
-                        self.plugin_view.PositionAtCenter)
-                self.plugin_view.scrollTo(idx,
-                        self.plugin_view.PositionAtCenter)
-                self.plugin_view.selectionModel().select(idx,
-                        self.plugin_view.selectionModel().ClearAndSelect)
-                self.plugin_view.setCurrentIndex(idx)
+                self.highlight_index(idx)
         else:
             error_dialog(self, _('No valid plugin path'),
                          _('%s is not a valid plugin path')%path).exec_()
