@@ -693,10 +693,7 @@ def command_catalog(args, dbpath):
                             }
 
     with plugin:
-        plugin.run(args[1], opts, get_db(dbpath, opts))
-    return 0
-
-# end of GR additions
+        return int(bool(plugin.run(args[1], opts, get_db(dbpath, opts))))
 
 def parse_series_string(db, label, value):
     val = unicode(value).strip()
@@ -986,8 +983,8 @@ def command_restore_database(args, dbpath):
         return 1
 
     if not opts.really_do_it:
-        prints(_('You must provide the --really-do-it option to do a'
-            ' recovery'), end='\n\n')
+        prints(_('You must provide the %s option to do a'
+            ' recovery')%'--really-do-it', end='\n\n')
         parser.print_help()
         return 1
 
