@@ -10,7 +10,10 @@ from calibre.utils.ordered_dict import OrderedDict
 
 class Cache(object):
 
-    def add_routes(self, c):
+    def __init__(self):
+        self.reset_caches()
+
+    def reset_caches(self):
         self._category_cache = OrderedDict()
         self._search_cache = OrderedDict()
 
@@ -29,6 +32,11 @@ class Cache(object):
 
 
     def categories_cache(self, restrict_to=frozenset([])):
+        base_restriction = self.search_cache('')
+        if restrict_to:
+            restrict_to = frozenset(restrict_to).intersection(base_restriction)
+        else:
+            restrict_to = base_restriction
         old = self._category_cache.pop(frozenset(restrict_to), None)
         if old is None or old[0] <= self.db.last_modified():
             categories = self.db.get_categories(ids=restrict_to)
