@@ -7,26 +7,32 @@ __docformat__ = 'restructuredtext en'
 
 import re, os
 import __builtin__
+from urllib import quote
 
 import cherrypy
 from lxml import html
 from lxml.html.builder import HTML, HEAD, TITLE, LINK, DIV, IMG, BODY, \
         OPTION, SELECT, INPUT, FORM, SPAN, TABLE, TR, TD, A, HR
 
+from calibre.library.server import custom_fields_to_display
 from calibre.library.server.utils import strftime, format_tag_string
 from calibre.ebooks.metadata import fmt_sidx
 from calibre.constants import __appname__
-from calibre import human_readable
-from calibre.utils.date import utcfromtimestamp, format_date
+from calibre import human_readable, isbytestring
+from calibre.utils.date import utcfromtimestamp
+from calibre.utils.filenames import ascii_filename
+from calibre.utils.icu import sort_key
 
 def CLASS(*args, **kwargs): # class is a reserved word in Python
     kwargs['class'] = ' '.join(args)
     return kwargs
 
 
-def build_search_box(num, search, sort, order): # {{{
+def build_search_box(num, search, sort, order, prefix): # {{{
     div = DIV(id='search_box')
-    form = FORM('Show ', method='get', action='mobile')
+    form = FORM('Show ', method='get', action=prefix+'/mobile')
+    form.set('accept-charset', 'UTF-8')
+
     div.append(form)
 
     num_select = SELECT(name='num')
@@ -85,11 +91,12 @@ def build_navigation(start, num, total, url_base): # {{{
 
     # }}}
 
-def build_index(books, num, search, sort, order, start, total, url_base, CKEYS):
-    logo = DIV(IMG(src='/static/calibre.png', alt=__appname__), id='logo')
+def build_index(books, num, search, sort, order, start, total, url_base, CKEYS,
+        prefix):
+    logo = DIV(IMG(src=prefix+'/static/calibre.png', alt=__appname__), id='logo')
 
-    search_box = build_search_box(num, search, sort, order)
-    navigation = build_navigation(start, num, total, url_base)
+    search_box = build_search_box(num, search, sort, order, prefix)
+    navigation = build_navigation(start, num, total, prefix+url_base)
     bookt = TABLE(id='listing')
 
     body = BODY(
@@ -103,24 +110,28 @@ def build_index(books, num, search, sort, order, start, total, url_base, CKEYS):
     # Book list {{{
     for book in books:
         thumbnail = TD(
-                IMG(type='image/jpeg', border='0', src='/get/thumb/%s' %
+                IMG(type='image/jpeg', border='0',
+                    src=prefix+'/get/thumb/%s' %
                             book['id']),
                 CLASS('thumbnail'))
 
         data = TD()
-        last = None
         for fmt in book['formats'].split(','):
+            a = quote(ascii_filename(book['authors']))
+            t = quote(ascii_filename(book['title']))
             s = SPAN(
                 A(
                     fmt.lower(),
-                    href='/get/%s/%s-%s_%d.%s' % (fmt, book['authors'],
-                        book['title'], book['id'], fmt)
+                    href=prefix+'/get/%s/%s-%s_%d.%s' % (fmt, a, t,
+                        book['id'], fmt.lower())
                 ),
                 CLASS('button'))
-            s.tail = u'\u202f' # &nbsp;
-            last = s
+            s.tail = u''
             data.append(s)
 
+        div = DIV(CLASS('data-container'))
+        data.append(div)
+
         series = u'[%s - %s]'%(book['series'], book['series_index']) \
                 if book['series'] else ''
         tags = u'Tags=[%s]'%book['tags'] if book['tags'] else ''
@@ -131,13 +142,13 @@ def build_index(books, num, search, sort, order, start, total, url_base, CKEYS):
             if val:
                 ctext += '%s=[%s] '%tuple(val.split(':#:'))
 
-        text = u'\u202f%s %s by %s - %s - %s %s %s' % (book['title'], series,
-                book['authors'], book['size'], book['timestamp'], tags, ctext)
-
-        if last is None:
-            data.text = text
-        else:
-            last.tail += text
+        first = SPAN(u'\u202f%s %s by %s' % (book['title'], series,
+            book['authors']), CLASS('first-line'))
+        div.append(first)
+        second = SPAN(u'%s - %s %s %s' % ( book['size'],
+            book['timestamp'],
+            tags, ctext), CLASS('second-line'))
+        div.append(second)
 
         bookt.append(TR(thumbnail, data))
     # }}}
@@ -147,7 +158,7 @@ def build_index(books, num, search, sort, order, start, total, url_base, CKEYS):
             TITLE(__appname__ + ' Library'),
             LINK(rel='icon', href='http://calibre-ebook.com/favicon.ico',
                 type='image/x-icon'),
-            LINK(rel='stylesheet', type='text/css', href='/mobile/style.css')
+            LINK(rel='stylesheet', type='text/css', href=prefix+'/mobile/style.css')
         ), # End head
         body
     ) # End html
@@ -167,7 +178,9 @@ class MobileServer(object):
         cherrypy.response.headers['Content-Type'] = 'text/css; charset=utf-8'
         updated = utcfromtimestamp(os.stat(path).st_mtime)
         cherrypy.response.headers['Last-Modified'] = self.last_modified(updated)
-        return open(path, 'rb').read()
+        with open(path, 'rb') as f:
+            ans = f.read()
+        return ans.replace('{prefix}', self.opts.url_prefix)
 
     def mobile(self, start='1', num='25', sort='date', search='',
                 _=None, order='descending'):
@@ -189,6 +202,8 @@ class MobileServer(object):
             raise cherrypy.HTTPError(400, 'num: %s is not an integer'%num)
         if not search:
             search = ''
+        if isbytestring(search):
+            search = search.decode('UTF-8')
         ids = self.db.search_getting_ids(search.strip(), self.search_restriction)
         FM = self.db.FIELD_MAP
         items = [r for r in iter(self.db) if r[FM['id']] in ids]
@@ -196,9 +211,12 @@ class MobileServer(object):
             self.sort(items, sort, (order.lower().strip() == 'ascending'))
 
         CFM = self.db.field_metadata
-        CKEYS = [key for key in sorted(CFM.get_custom_fields(),
-             cmp=lambda x,y: cmp(CFM[x]['name'].lower(),
-                                 CFM[y]['name'].lower()))]
+        CKEYS = [key for key in sorted(custom_fields_to_display(self.db),
+                                       key=lambda x:sort_key(CFM[x]['name']))]
+        # This method uses its own book dict, not the Metadata dict. The loop
+        # below could be changed to use db.get_metadata instead of reading
+        # info directly from the record made by the view, but it doesn't seem
+        # worth it at the moment.
         books = []
         for record in items[(start-1):(start-1)+num]:
             book = {'formats':record[FM['formats']], 'size':record[FM['size']]}
@@ -213,36 +231,29 @@ class MobileServer(object):
             book['authors'] = authors
             book['series_index'] = fmt_sidx(float(record[FM['series_index']]))
             book['series'] = record[FM['series']]
-            book['tags'] = format_tag_string(record[FM['tags']], ',')
+            book['tags'] = format_tag_string(record[FM['tags']], ',',
+                                             no_tag_count=True)
             book['title'] = record[FM['title']]
             for x in ('timestamp', 'pubdate'):
-                book[x] = strftime('%Y/%m/%d %H:%M:%S', record[FM[x]])
+                book[x] = strftime('%d %b, %Y', record[FM[x]])
             book['id'] = record[FM['id']]
             books.append(book)
             for key in CKEYS:
                 def concat(name, val):
                     return '%s:#:%s'%(name, unicode(val))
-                val = record[CFM[key]['rec_index']]
-                if val:
-                    datatype = CFM[key]['datatype']
-                    if datatype in ['comments']:
-                        continue
-                    name = CFM[key]['name']
-                    if datatype == 'text' and CFM[key]['is_multiple']:
-                        book[key] = concat(name, format_tag_string(val, '|'))
-                    elif datatype == 'series':
-                        book[key] = concat(name, '%s [%s]'%(val,
-                            fmt_sidx(record[CFM.cc_series_index_column_for(key)])))
-                    elif datatype == 'datetime':
-                        book[key] = concat(name,
-                            format_date(val, CFM[key]['display'].get('date_format','dd MMM yyyy')))
-                    elif datatype == 'bool':
-                        if val:
-                            book[key] = concat(name, __builtin__._('Yes'))
-                        else:
-                            book[key] = concat(name, __builtin__._('No'))
-                    else:
-                        book[key] = concat(name, val)
+                mi = self.db.get_metadata(record[CFM['id']['rec_index']], index_is_id=True)
+                name, val = mi.format_field(key)
+                if not val:
+                    continue
+                datatype = CFM[key]['datatype']
+                if datatype in ['comments']:
+                    continue
+                if datatype == 'text' and CFM[key]['is_multiple']:
+                    book[key] = concat(name,
+                                       format_tag_string(val, ',',
+                                                         no_tag_count=True))
+                else:
+                    book[key] = concat(name, val)
 
         updated = self.db.last_modified()
 
@@ -253,7 +264,8 @@ class MobileServer(object):
         url_base = "/mobile?search=" + search+";order="+order+";sort="+sort+";num="+str(num)
 
         return html.tostring(build_index(books, num, search, sort, order,
-                             start, len(ids), url_base, CKEYS),
+                             start, len(ids), url_base, CKEYS,
+                             self.opts.url_prefix),
                              encoding='utf-8', include_meta_content_type=True,
                              pretty_print=True)
 
