@@ -104,12 +104,13 @@ class cmd_commit(_cmd_commit):
 
     def close_bug(self, bug, action, url, config):
         print 'Closing bug #%s'% bug
-        nick = config.get_nickname()
+        #nick = config.get_nickname()
         suffix = config.get_user_option('bug_close_comment')
         if suffix is None:
             suffix = 'The fix will be in the next release.'
         action = action+'ed'
-        msg = '%s in branch %s. %s'%(action, nick, suffix)
+        msg = '%s in branch %s. %s'%(action, 'lp:calibre', suffix)
+        msg = msg.replace('Fixesed', 'Fixed')
         server = xmlrpclib.ServerProxy(url)
         server.ticket.update(int(bug), msg,
                              {'status':'closed', 'resolution':'fixed'},
