@@ -6,35 +6,19 @@ __docformat__ = 'restructuredtext en'
 '''
 Manage application-wide preferences.
 '''
-import os, re, cPickle, textwrap, traceback, plistlib, json, base64
+import os, re, cPickle, textwrap, traceback, plistlib, json, base64, datetime
 from copy import deepcopy
 from functools import partial
 from optparse import OptionParser as _OptionParser
 from optparse import IndentedHelpFormatter
-from calibre.constants import terminal_controller, iswindows, isosx, \
-                              __appname__, __version__, __author__, plugins
-from calibre.utils.lock import LockError, ExclusiveFile
 from collections import defaultdict
 
-if os.environ.has_key('CALIBRE_CONFIG_DIRECTORY'):
-    config_dir = os.path.abspath(os.environ['CALIBRE_CONFIG_DIRECTORY'])
-elif iswindows:
-    if plugins['winutil'][0] is None:
-        raise Exception(plugins['winutil'][1])
-    config_dir = plugins['winutil'][0].special_folder_path(plugins['winutil'][0].CSIDL_APPDATA)
-    if not os.access(config_dir, os.W_OK|os.X_OK):
-        config_dir = os.path.expanduser('~')
-    config_dir = os.path.join(config_dir, 'calibre')
-elif isosx:
-    config_dir = os.path.expanduser('~/Library/Preferences/calibre')
-else:
-    bdir = os.path.abspath(os.path.expanduser(os.environ.get('XDG_CONFIG_HOME', '~/.config')))
-    config_dir = os.path.join(bdir, 'calibre')
+from calibre.constants import terminal_controller, config_dir, CONFIG_DIR_MODE, \
+                              __appname__, __version__, __author__
+from calibre.utils.lock import LockError, ExclusiveFile
 
 plugin_dir = os.path.join(config_dir, 'plugins')
 
-CONFIG_DIR_MODE = 0700
-
 def make_config_dir():
     if not os.path.exists(plugin_dir):
         os.makedirs(plugin_dir, mode=CONFIG_DIR_MODE)
@@ -208,6 +192,7 @@ class OptionSet(object):
 
     def __init__(self, description=''):
         self.description = description
+        self.defaults = {}
         self.preferences = []
         self.group_list  = []
         self.groups      = {}
@@ -288,6 +273,7 @@ class OptionSet(object):
         if pref in self.preferences:
             raise ValueError('An option with the name %s already exists in this set.'%name)
         self.preferences.append(pref)
+        self.defaults[name] = default
 
     def option_parser(self, user_defaults=None, usage='', gui_mode=False):
         parser = OptionParser(usage, gui_mode=gui_mode)
@@ -326,10 +312,10 @@ class OptionSet(object):
 
     def parse_string(self, src):
         options = {'cPickle':cPickle}
-        if not isinstance(src, unicode):
-            src = src.decode('utf-8')
         if src is not None:
             try:
+                if not isinstance(src, unicode):
+                    src = src.decode('utf-8')
                 exec src in options
             except:
                 print 'Failed to parse options string:'
@@ -480,6 +466,10 @@ class ConfigProxy(object):
         self.__config = config
         self.__opts   = None
 
+    @property
+    def defaults(self):
+        return self.__config.option_set.defaults
+
     def refresh(self):
         self.__opts = self.__config.parse()
 
@@ -500,6 +490,9 @@ class ConfigProxy(object):
         setattr(self.__opts, key, val)
         return self.__config.set(key, val)
 
+    def help(self, key):
+        return self.__config.get_option(key).help
+
 class DynamicConfig(dict):
     '''
     A replacement for QSettings that supports dynamic config keys.
@@ -510,6 +503,7 @@ class DynamicConfig(dict):
     def __init__(self, name='dynamic'):
         dict.__init__(self, {})
         self.name = name
+        self.defaults = {}
         self.file_path = os.path.join(config_dir, name+'.pickle')
         self.refresh()
 
@@ -534,7 +528,13 @@ class DynamicConfig(dict):
         try:
             return dict.__getitem__(self, key)
         except KeyError:
-            return None
+            return self.defaults.get(key, None)
+
+    def get(self, key, default=None):
+        try:
+            return dict.__getitem__(self, key)
+        except KeyError:
+            return self.defaults.get(key, default)
 
     def __setitem__(self, key, val):
         dict.__setitem__(self, key, val)
@@ -569,6 +569,7 @@ class XMLConfig(dict):
 
     def __init__(self, rel_path_to_cf_file):
         dict.__init__(self)
+        self.defaults = {}
         self.file_path = os.path.join(config_dir,
                 *(rel_path_to_cf_file.split('/')))
         self.file_path = os.path.abspath(self.file_path)
@@ -606,7 +607,16 @@ class XMLConfig(dict):
                 ans = ans.data
             return ans
         except KeyError:
-            return None
+            return self.defaults.get(key, None)
+
+    def get(self, key, default=None):
+        try:
+            ans = dict.__getitem__(self, key)
+            if isinstance(ans, plistlib.Data):
+                ans = ans.data
+            return ans
+        except KeyError:
+            return self.defaults.get(key, default)
 
     def __setitem__(self, key, val):
         if isinstance(val, (bytes, str)):
@@ -618,8 +628,9 @@ class XMLConfig(dict):
         self.__setitem__(key, val)
 
     def __delitem__(self, key):
-        dict.__delitem__(self, key)
-        self.commit()
+        if dict.has_key(self, key):
+            dict.__delitem__(self, key)
+            self.commit()
 
     def commit(self):
         if hasattr(self, 'file_path') and self.file_path:
@@ -632,30 +643,46 @@ class XMLConfig(dict):
                 f.truncate()
                 f.write(raw)
 
+def to_json(obj):
+    if isinstance(obj, bytearray):
+        return {'__class__': 'bytearray',
+                '__value__': base64.standard_b64encode(bytes(obj))}
+    if isinstance(obj, datetime.datetime):
+        from calibre.utils.date import isoformat
+        return {'__class__': 'datetime.datetime',
+                '__value__': isoformat(obj, as_utc=True)}
+    raise TypeError(repr(obj) + ' is not JSON serializable')
+
+def from_json(obj):
+    if '__class__' in obj:
+        if obj['__class__'] == 'bytearray':
+            return bytearray(base64.standard_b64decode(obj['__value__']))
+        if obj['__class__'] == 'datetime.datetime':
+            from calibre.utils.date import parse_date
+            return parse_date(obj['__value__'], assume_utc=True)
+    return obj
+
 class JSONConfig(XMLConfig):
 
     EXTENSION = '.json'
 
-    def to_json(self, obj):
-        if isinstance(obj, bytearray):
-            return {'__class__': 'bytearray',
-                    '__value__': base64.standard_b64encode(bytes(obj))}
-        raise TypeError(repr(obj) + ' is not JSON serializable')
-
-    def from_json(self, obj):
-        if '__class__' in obj:
-            if obj['__class__'] == 'bytearray':
-                return bytearray(base64.standard_b64decode(obj['__value__']))
-        return obj
-
     def raw_to_object(self, raw):
-        return json.loads(raw.decode('utf-8'), object_hook=self.from_json)
+        return json.loads(raw.decode('utf-8'), object_hook=from_json)
 
     def to_raw(self):
-        return json.dumps(self, indent=2, default=self.to_json)
+        return json.dumps(self, indent=2, default=to_json)
 
     def __getitem__(self, key):
-        return dict.__getitem__(self, key)
+        try:
+            return dict.__getitem__(self, key)
+        except KeyError:
+            return self.defaults[key]
+
+    def get(self, key, default=None):
+        try:
+            return dict.__getitem__(self, key)
+        except KeyError:
+            return self.defaults.get(key, default)
 
     def __setitem__(self, key, val):
         dict.__setitem__(self, key, val)
@@ -681,7 +708,7 @@ def _prefs():
     c.add_opt('output_format', default='EPUB',
               help=_('The default output format for ebook conversions.'))
     c.add_opt('input_format_order', default=['EPUB', 'MOBI', 'LIT', 'PRC',
-        'FB2', 'HTML', 'HTM', 'XHTM', 'SHTML', 'XHTML', 'ODT', 'RTF', 'PDF',
+        'FB2', 'HTML', 'HTM', 'XHTM', 'SHTML', 'XHTML', 'ZIP', 'ODT', 'RTF', 'PDF',
         'TXT'],
               help=_('Ordered list of formats to prefer for input.'))
     c.add_opt('read_file_metadata', default=True,
@@ -693,13 +720,14 @@ def _prefs():
     c.add_opt('add_formats_to_existing', default=False,
             help=_('Add new formats to existing book records'))
     c.add_opt('installation_uuid', default=None, help='Installation UUID')
+    c.add_opt('new_book_tags', default=[], help=_('Tags to apply to books added to the library'))
 
     # these are here instead of the gui preferences because calibredb and
     # calibre server can execute searches
     c.add_opt('saved_searches', default={}, help=_('List of named saved searches'))
     c.add_opt('user_categories', default={}, help=_('User-created tag browser categories'))
-    c.add_opt('preserve_user_collections', default=True,
-        help=_('Preserve all collections even if not in library metadata.'))
+    c.add_opt('manage_device_metadata', default='manual',
+        help=_('How and when calibre updates metadata on the device.'))
 
     c.add_opt('migrated', default=False, help='For Internal use. Don\'t modify.')
     return c
@@ -710,16 +738,22 @@ if prefs['installation_uuid'] is None:
     prefs['installation_uuid'] = str(uuid.uuid4())
 
 # Read tweaks
-def read_tweaks():
+def read_raw_tweaks():
     make_config_dir()
-    default_tweaks = P('default_tweaks.py', data=True)
+    default_tweaks = P('default_tweaks.py', data=True,
+            allow_user_override=False)
     tweaks_file = os.path.join(config_dir, 'tweaks.py')
     if not os.path.exists(tweaks_file):
         with open(tweaks_file, 'wb') as f:
             f.write(default_tweaks)
+    with open(tweaks_file, 'rb') as f:
+        return default_tweaks, f.read()
+
+def read_tweaks():
+    default_tweaks, tweaks = read_raw_tweaks()
     l, g = {}, {}
     try:
-        exec open(tweaks_file, 'rb') in g, l
+        exec tweaks in g, l
     except:
         print 'Failed to load custom tweaks file'
         traceback.print_exc()
@@ -728,6 +762,13 @@ def read_tweaks():
     dl.update(l)
     return dl
 
+def write_tweaks(raw):
+    make_config_dir()
+    tweaks_file = os.path.join(config_dir, 'tweaks.py')
+    with open(tweaks_file, 'wb') as f:
+        f.write(raw)
+
+
 tweaks = read_tweaks()
 
 def migrate():
