@@ -46,6 +46,17 @@ local_tz = _local_tz = SafeLocalTimeZone()
 
 UNDEFINED_DATE = datetime(101,1,1, tzinfo=utc_tz)
 
+def is_date_undefined(qt_or_dt):
+    d = qt_or_dt
+    if d is None:
+        return True
+    if hasattr(d, 'toString'):
+        d = datetime(d.year(), d.month(), d.day(), tzinfo=utc_tz)
+    return d.year < UNDEFINED_DATE.year or (
+            d.year == UNDEFINED_DATE.year and
+            d.month == UNDEFINED_DATE.month and
+            d.day == UNDEFINED_DATE.day)
+
 def parse_date(date_string, assume_utc=False, as_utc=True, default=None):
     '''
     Parse a date/time string into a timezone aware datetime object. The timezone
@@ -148,6 +159,9 @@ def format_date(dt, format, assume_utc=False, as_utc=False):
         if len(mo.group(0)) == 2: return '%02d'%(dt.year % 100)
         return '%04d'%dt.year
 
+    if dt == UNDEFINED_DATE:
+        return ''
+
     format = re.sub('d{1,4}', format_day, format)
     format = re.sub('M{1,4}', format_month, format)
     return re.sub('yyyy|yy', format_year, format)
