@@ -8,7 +8,7 @@ __docformat__ = 'restructuredtext en'
 
 import subprocess, os, sys, time, binascii, cPickle
 
-from calibre.constants import iswindows, isosx, isfrozen, isnewosx
+from calibre.constants import iswindows, isosx, isfrozen
 from calibre.utils.config import prefs
 from calibre.ptempfile import PersistentTemporaryFile, base_dir
 
@@ -51,17 +51,11 @@ class Worker(object):
             return os.path.join(os.path.dirname(sys.executable),
                    e+'.exe' if isfrozen else \
                            'Scripts\\%s.exe'%e)
-        if isnewosx:
+        if isosx:
             return os.path.join(sys.console_binaries_path, e)
 
-        if isosx:
-            if not isfrozen: return e
-            contents = os.path.join(self.osx_contents_dir,
-                    'console.app', 'Contents')
-            return os.path.join(contents, 'MacOS', self.osx_interpreter)
-
         if isfrozen:
-            return os.path.join(getattr(sys, 'frozen_path'), e)
+            return os.path.join(sys.executables_location, e)
 
         c = os.path.join(sys.executables_location, e)
         if os.access(c, os.X_OK):
@@ -71,13 +65,9 @@ class Worker(object):
 
     @property
     def gui_executable(self):
-        if isnewosx:
+        if isosx:
            return os.path.join(sys.binaries_path, self.exe_name)
 
-        if isfrozen and isosx:
-            return os.path.join(self.osx_contents_dir,
-                    'MacOS', self.osx_interpreter)
-
         return self.executable
 
     @property
@@ -123,27 +113,6 @@ class Worker(object):
     def __init__(self, env, gui=False):
         self._env = {}
         self.gui = gui
-        if isosx and isfrozen and not isnewosx:
-            contents = os.path.join(self.osx_contents_dir, 'console.app', 'Contents')
-            resources = os.path.join(contents, 'Resources')
-            fd = os.path.join(contents, 'Frameworks')
-            sp = os.path.join(resources, 'lib', 'python'+sys.version[:3], 'site-packages.zip')
-            self.osx_prefix = 'import sys, os; sys.frameworks_dir = "%s"; sys.frozen = "macosx_app"; '%fd
-            self.osx_prefix += 'sys.path.insert(0, %s); '%repr(sp)
-            self.osx_prefix += 'sys.extensions_location = os.path.join(sys.frameworks_dir, "plugins");'
-            self.osx_prefix += 'sys.resources_location = os.path.join(os.path.dirname(sys.frameworks_dir), "Resources", "resources"); '
-
-            self._env['PYTHONHOME']  = resources
-            self._env['MAGICK_HOME'] = os.path.join(fd, 'ImageMagick')
-            self._env['DYLD_LIBRARY_PATH'] = os.path.join(fd, 'ImageMagick', 'lib')
-            self._env['FONTCONFIG_PATH'] = \
-                os.path.join(os.path.realpath(resources), 'fonts')
-            self._env['QT_PLUGIN_PATH'] = \
-                    os.path.join(self.osx_contents_dir, 'MacOS')
-
-        if isfrozen and not (iswindows or isosx):
-            self._env['LD_LIBRARY_PATH'] = getattr(sys, 'frozen_path') + ':'\
-                    + os.environ.get('LD_LIBRARY_PATH', '')
         self._env.update(env)
 
     def __call__(self, redirect_output=True, cwd=None, priority=None):
@@ -155,13 +124,9 @@ class Worker(object):
         env = self.env
         env['ORIGWD'] = cwd or os.path.abspath(os.getcwd())
         _cwd = cwd
-        if isfrozen and not iswindows and not isosx:
-            _cwd = getattr(sys, 'frozen_path', None)
         if priority is None:
             priority = prefs['worker_process_priority']
         cmd = [exe]
-        if isosx and not isnewosx:
-            cmd += ['-c', self.osx_prefix + 'from calibre.utils.ipc.worker import main; main()']
         args = {
                 'env' : env,
                 'cwd' : _cwd,
