@@ -112,6 +112,16 @@ _extra_lang_codes = {
         'en_IE' : _('English (Ireland)'),
         'en_CN' : _('English (China)'),
         'es_PY' : _('Spanish (Paraguay)'),
+        'es_UY' : _('Spanish (Uruguay)'),
+        'es_AR' : _('Spanish (Argentina)'),
+        'es_MX' : _('Spanish (Mexico)'),
+        'es_CU' : _('Spanish (Cuba)'),
+        'es_CL' : _('Spanish (Chile)'),
+        'es_EC' : _('Spanish (Ecuador)'),
+        'es_HN' : _('Spanish (Honduras)'),
+        'es_VE' : _('Spanish (Venezuela)'),
+        'es_BO' : _('Spanish (Bolivia)'),
+        'es_NI' : _('Spanish (Nicaragua)'),
         'de_AT' : _('German (AT)'),
         'fr_BE' : _('French (BE)'),
         'nl'    : _('Dutch (NL)'),
