@@ -166,7 +166,7 @@ class Feed(object):
                 self.articles.append(article)
             else:
                 t = strftime(u'%a, %d %b, %Y %H:%M', article.localtime.timetuple())
-                self.logger.debug('Skipping article %s (%s) from feed %s as it is too old.'%
+                self.logger.debug(u'Skipping article %s (%s) from feed %s as it is too old.'%
                         (title, t, self.title))
             d = item.get('date', '')
             article.formatted_date = d
